require "lib"

name = "Arrow"
key = "option-a"
menu_position = 201
custom_pen = true
submenu = "Complex Geometry"
radius = 3

parameters = {"double_sided", "tip_width", "tip_length"}

double_sided = 0; double_sided_min = 0; double_sided_max = 1;
tip_width = 10; tip_width_min = 2; tip_width_max = 40;
tip_length = 15; tip_length_min = 2; tip_length_max = 40;

icon = "arrow_icon"
icon_position = 10

-- Custom drawing

arrow = clone(basic_drag_tool)

function arrow:stem()
	local bp = bezier_path()
	if shift_down() then
		local dir = self._end - self._start
		local len = length(dir)
		angle = math.atan2(dir.y, dir.x)
		dir = vector{x = math.cos(angle), y = math.sin(angle)}
		self._end = self._start + dir * len
	end
	local l = tip_length / scale()
	local d = normalize(self._end - self._start)
	if double_sided == 1 then
		move_to_point(bp, self._start + d*l/2)
	else
		move_to_point(bp, self._start)
	end
	line_to_point(bp, self._end - d*l/2)
	set_line_width(bp, self._lw);
	return bp
end

function arrow:tip()
	return lib.arrow_tip(self._start, self._end, tip_width, tip_length)
end

function arrow:butt()
	return lib.arrow_tip(self._end, self._start, tip_width, tip_length)
end

function arrow:preview()
	stroke(self:stem())
	fill(self:tip())
	if double_sided == 1 then
		fill(self:butt())
	end
end
	
function arrow:draw()
	add_stroke(arrow:stem())
	add_fill(arrow:tip())
	if double_sided == 1 then
		add_fill(self:butt())
	end
end

arrow:make_callbacks()